Learn R Programming

apTreeshape (version 1.5-0.1)

aux_lik: Probability of the sampled node position

Description

Probability of the sampled node position knowing the tree topology, the number of unsampled nodes and the interval sizes

Usage

aux_lik(M, beta, alpha)

Arguments

M

An oject returned by the function transform

beta

Imbalance index

alpha

Clade age-richness index