The beta-splitting model has been introduced by Aldous to simulate trees with different tree balance.
Beta=0 corresponds to Yule trees.
Beta<0 corresponds to trees more unbalanced than Yule trees, Beta=-3/2 corresponds to the PDA model.
Beta>0 corresponds to trees more balanced than Yule trees.
By default, confidence.interval="none" and no confidence interval is computed.
When confidence.interval="bootstrap", a confidence interval is found with a
resampling technique. Shall be used when the number of tips is small (<50).
When confidence.interval="profile", a confidence interval is found with a
profile likelihood technique. Shall be used when the number of tips is large (>50).