powered by
Probability of the sampled node position knowing the tree topology, the number of unsampled nodes and the interval sizes
aux_lik(M, beta, alpha)
An oject returned by the function transform
Imbalance index
Clade age-richness index